<?php
/**
 * WC_Shipping_FlavorCloud class.
 *
 * @class 		WC_Shipping_FlavorCloud
 * @version		1.0.0
 * @package		FlavorCloud-for-WooCommerce/Classes
 * @category	Class
 * @author 		Qwebmaster
 */
class WC_Shipping_FlavorCloud extends WC_Shipping_Method {

    /**
	 * FlavorCloud endpoint and Credentials.
	 */
	private $endpoint = 'https://partnerapi.flavorcloud.com/Rates';
    //public $appID = get_option( 'fcsfw_appID' );
    //private $restAPIKey = get_option( 'fcsfw_restAPIKey' );
    // Unit for weight of the shipment. Possible values are - KG|LB
    private $weight_unit = "LB";
    private $debug = 'yes';
    // $this->restAPIKey 

	/**
	 * Constructor. The instance ID is passed to this.
	 */
	public function __construct( $instance_id = 0 ) {
		$this->id                    = 'flavor-cloud';
		$this->instance_id           = absint( $instance_id );
		$this->method_title          = __( 'FlavorCloud Shipping Method' );
		$this->method_description    = __( 'FlavorCloud Shipping method, Live API Shipping Rates.' );
		$this->supports              = array(
			'shipping-zones',
			'instance-settings',
            'instance-settings-modal',
		);
		$this->instance_form_fields = array(
			'enabled' => array(
				'title' 		=> __( 'Enable/Disable' ),
				'type' 			=> 'checkbox',
				'label' 		=> __( 'Enable this shipping method' ),
				'default' 		=> 'yes',
			),
			'title' => array(
				'title' 		=> __( 'Method Title' ),
				'type' 			=> 'text',
				'description' 	=> __( 'This controls the title prefix which the user sees during checkout.' ),
				'default'		=> __( 'Flavor Cloud' ),
				'desc_tip'		=> true
			)
		);
		$this->enabled              = $this->get_option( 'enabled' );
		$this->title                = $this->get_option( 'title' );
        $this->init();
		//add_action( 'woocommerce_update_options_shipping_' . $this->id, array( $this, 'process_admin_options' ) );
	}

    /**
	 * Initialization.
	 *
	 * @return void
	 */
	private function init() {

		// Load the settings.
		//$this->init_form_fields();
		//$this->set_settings();
		add_action( 'woocommerce_update_options_shipping_' . $this->id, array( $this, 'process_admin_options' ) );
        add_action( 'woocommerce_update_options_shipping_' . $this->id, array( $this, 'clear_transients' ) );
	}

	/**
	 * Output a debug message.
	 *
	 * @param string $message Debug message.
	 * @param string $type    Message type.
	 */
	public function debug( $message, $type = 'notice' ) {
		if ( $this->debug || ( current_user_can( 'manage_options' ) && 'error' == $type ) ) {
			wc_add_notice( $message, $type );
		}
	}

    /**
	 * Clear FlavorCloud transients.
	 */
	public function clear_transients() {
		global $wpdb;
		$wpdb->query( "DELETE FROM `$wpdb->options` WHERE `option_name` LIKE ('_transient_flavorcloud_quote_%') OR `option_name` LIKE ('_transient_timeout_flavorcloud_quote_%')" );
	}


    /**
     * Get FlavorCloud Shipping Rates via API function.
     */
    public function Flavor_Cloud_API_GetRates($pieces, $quote_box, $ShipToAddress, $ShipFromAddress='' ) {

    $main_data = FlavorCloud_API_Get_Settings('API');
    $FLCLShippingServiceURL = $main_data['endpoints']['Rates'];   

    //fcsfw_print_array($main_data['TermsOfTrade']);
    //die();

    $args = array(
        'AppID' => $main_data['appID'],
        'RestApiKey' => $main_data['restAPIKey'],
        'CustomerKey' => "",
        'Reference' => "1234567",
        'LabelFormat' => "PDF",
        'WeightUnit' => $main_data['weight_unit'],
        'Currency' => "USD",
        'DimensionUnit' => "IN",
        'Insurance' => "N",
        'ServiceCode' => array(
            "STANDARD",
            "EXPRESS",
            "ECONOMY" 
        ),
        'TermsOfTrade' => array(
            $main_data['TermsOfTrade']
        ),
        'IsReturn' => "N",
        'IncludeLandedCost' => true,
        'ShipFromAddress' => FlavorCloud_API_Get_Settings('ShipFromAddress'),
        'ShipToAddress' => $ShipToAddress,
        "Pieces" => $pieces,
        'Package' => array(
            'Length' => $quote_box['Length'],
            'Width' => $quote_box['Width'],
            'Height' => $quote_box['Height'],
            'Weight' => $quote_box['Weight']
        ),
        'ReasonForExport' => "Sale"
    );
        
    $arg_header = array(
            'content-type' => 'application/json',
            'accept' => 'application/json',
    );


    //fcsfw_print_array($args);
    //fcsfw_print_array(json_encode($args));
    //die();

    // Check Cache Before doing API Request 
    // Build Transient, to be retreved later when the order is made. 
    // The info will be used to create a shipping label
    //$transient_id = $ShipToAddress['AddressLine1'].$ShipToAddress['State'].$ShipToAddress['Email'];
    $transient = 'flavorcloud_quote_' . md5( json_encode($args));

    $cached_response  = get_transient($transient);

    //fcsfw_print_array($transient);
    //echo json_encode($args);
    //fcsfw_print_array( json_encode($args) );
    //die();


    // AIT = Advance Income Tax

    if ( false === $cached_response ) {
    $response = wp_remote_post($FLCLShippingServiceURL, array(
        'headers'   => $arg_header,
        'body'      => json_encode($args),
        'method'    => 'POST'
    ));

    //$this->debug( fcsfw_print_array(fcsfw_print_array($response)));
    //die();

    if ( is_wp_error( $response ) ) {
        //$this->debug( __( 'Cannot retrieve FlavorCloud rate: ', 'woocommerce-shipping-flavorcloud' ) . $response->get_error_message(), 'error' );
        //fcsfw_logger('Cannot retrieve FlavorCloud rate:'.$response->get_error_message());
    } else {
        // Response body.
        $body = wp_remote_retrieve_body( $response );
        // On success ($body is a valid JSON string), output the shipping methods Array 
        $responceData = ( ! is_wp_error( $response ) ) ? json_decode( $body, true ) : null;
        set_transient( $transient, $responceData, 12 * HOUR_IN_SECONDS );
        //fcsfw_logger( var_dump($responceData));
    }

    } else {
        $responceData = $cached_response;
        //$this->debug( __( 'Flavor Cloud: Using cached response.', 'woocommerce-shipping-flavorcloud' ) );
    }
    return $responceData;
}


	/**
	 * Shipping method is available only when destination county,zipcity,street are loaded.
	 *
	 * @param array $package Package to ship.
	 *
	 * @return bool True if shipping method is available.
	 */
	public function is_available( $package ) {
		if ( empty( $package['destination']['country'] ) || empty( $package['destination']['postcode'] ) || empty( $package['destination']['city'] )|| empty( $package['destination']['address'] ) ) {
			return false;
		}
		return apply_filters( 'woocommerce_shipping_' . $this->id . '_is_available', true, $package );
	}

    /**
     * calculate_shipping function.
     * @param array $package (default: array())
     */
    public function calculate_shipping( $package = array() ) {
        
            // Only return rates if the package has a destination including country.
            if ( '' === $package['destination']['country'] ) {
                $this->debug( __( 'FlavorCloud: Country not supplied. Rates not requested.', 'woocommerce-shipping-flavorcloud' ) );
                return;
            }
         //$this->debug( fcsfw_print_array($package['contents']));
        // Loop through shipping packages
        $ctr = 0;
        $items = array();
        $pieces = array();
        foreach( $package['contents'] as $item_id => $values ){

            //var_dump($values);
            //var_dump($values['line_total']);
            //get_line_total() – Calculate line total – useful for gateways.
           // $item_discounted_price = $values['line_total'] / $values['quantity'];
            //var_dump($item_discounted_price);
           //die();

            $ctr++;
            if ( ! $values['data']->needs_shipping() ) {
                $this->debug( sprintf( __( 'Product #%d is virtual. Skipping FlavorCloud Live Rate.', 'woocommerce-shipping-flavorcloud' ), $ctr ) );
                continue;
            }

            if ( ! $values['data']->get_weight() ) {
                $this->debug( sprintf( __( 'Product #%d is missing weight. Aborting FlavorCloud Live Rate.', 'woocommerce-shipping-flavorcloud' ), $ctr ), 'error' );
                return;
            }

            // Get package weight.
            $weight = wc_get_weight( $values['data']->get_weight(), 'lbs' );

            // Get package dimensions.
            if ( $values['data']->get_length() && $values['data']->get_height() && $values['data']->get_width() ) {
                $item_discounted_price = $values['line_total'] / $values['quantity'];
                $items[] = array(
                    'Name' => $values['data']->get_name(),
                    'Width' => (float)$values['data']->get_width(),
                    'Length' => (float)$values['data']->get_length(),
                    'Height' => (float)$values['data']->get_height(),
                    'Weight' => (float)$weight,
                    'Quantity' => (float)$values['quantity'],
                    'Price' => (float)$item_discounted_price,
                    'SKU' => $values['data']->get_SKU(),
                );
                $pieces[] = array(
                    'Quantity' => (float)$values['quantity'],
                    'Weight' => $weight,
                    'Length' => (float)$values['data']->get_length(),
                    'Width' => (float)$values['data']->get_width(),
                    'Height' => (float)$values['data']->get_height(),
                    'SalePrice' => (float)$item_discounted_price,
                    'HSCode' => $values['data']->get_meta('_hscode'),
                    'OriginCountryCode' => "US",
                    'Material' => $values['data']->get_meta('_material'),
                    'Description' => $values['data']->get_name(),
                    'SKU' => $values['data']->get_SKU(),
                    'Category' =>  array()
                );
            }

    }

            //$this->debug( fcsfw_print_array(json_encode($pieces) ) );
            $quote_box = FlavorCloud_API_BinPack( $items );
            //$this->debug( fcsfw_print_array($quote_box));

            // Build Ship to Address
            $ShipToAddress = array(
                'Name' => WC()->customer->get_shipping_first_name().' '.WC()->customer->get_shipping_last_name(),
                'AttentionName' => '',
                'AddressLine1' => WC()->customer->get_shipping_address(),
                'AddressLine2' => WC()->customer->get_shipping_address_2(),
                'AddressLine3' => '',
                'City' => WC()->customer->get_shipping_city(),
                'State' => WC()->customer->get_shipping_state(),
                'Country' => WC()->customer->get_shipping_country(),
                'Zip' => WC()->customer->get_shipping_postcode(),
                'Phone' => WC()->customer->get_billing_phone(),
                'Email' => WC()->customer->get_billing_email(),
            );

            //$this->debug(fcsfw_print_array( $ShipToAddress));
            //die();

            $reponce = $this->Flavor_Cloud_API_GetRates($pieces,$quote_box,$ShipToAddress);
            //$this->debug(fcsfw_print_array($reponce));
            //$option[$main_data['TermsOfTrade']]['LandedCostDetail']['Duty'];
            //$option[$main_data['TermsOfTrade']]['LandedCostDetail']['SalesTax'];


            //die();
            //$this->debug(fcsfw_print_array($reponce));
            //die();

            if (!empty($reponce)){
                $main_data = FlavorCloud_API_Get_Settings('API');
                //$this->debug(fcsfw_print_array($main_data));
                // If terms of trade is set to Customs Dutied Paid add feed to cart
                // Fee #1 SalesTax 
                // Fee #2 Duty


                //add_action( 'woocommerce_cart_calculate_fees','fcsfw_add_landed_cost' ); 


                global $woocommerce;
              // Make a shipping rate for each result
              $additional_fees = array();
              foreach ($reponce as $key => $option) {
                //$this->debug(fcsfw_print_array($reponce));
                //'TermsOfTrade' => 'DDP'
                // Make sure we are only processing the shipping rates 
                    if (is_array($option) && isset($option[$main_data['TermsOfTrade']])) {
                        //$this->debug(fcsfw_print_array($reponce));
                        $additional_fees[$key]=array(
                            'Duty' => $option[$main_data['TermsOfTrade']]['LandedCostDetail']['Duty'],
                            'SalesTax' => $option[$main_data['TermsOfTrade']]['LandedCostDetail']['SalesTax'],
                            'AIT' => $option[$main_data['TermsOfTrade']]['LandedCostDetail']['AIT'],
                            'LandedCost' => $option[$main_data['TermsOfTrade']]['LandedCostDetail']['LandedCost'],
                            'DutyHashKey' => $option[$main_data['TermsOfTrade']]['LandedCostDetail']['DutyHashKey']
                        );

if ($key == 'Standard') {
   if (!empty($main_data['fcsfw_standard_label'])) {
    $label = $main_data['fcsfw_standard_label'];
   } else {
    $label = $option[$main_data['TermsOfTrade']]['Carrier'].' '.$option[$main_data['TermsOfTrade']]['Days'];
   }
 }
 if ($key == 'Express') {
    if (!empty($main_data['fcsfw_express_label'])) {
     $label = $main_data['fcsfw_express_label'];
    } else {
     $label = $option[$main_data['TermsOfTrade']]['Carrier'].' '.$option[$main_data['TermsOfTrade']]['Days'];
    }
  }

 

                    $rate = array(
                    'id' => $key.'_'.$option[$main_data['TermsOfTrade']]['HashKey'].'_'.$option[$main_data['TermsOfTrade']]['LandedCostDetail']['DutyHashKey'],
                    //'label' => $methodNames[$option->name],
                    'label' => $label,
                    'cost' => $option[$main_data['TermsOfTrade']]['ShippingCost'],
                    'meta_data' => array(),
                    );

                    if ( $key == 'Standard' && $main_data['fcsfw_standard_disable'] !== 'yes' || $key == 'Express' && $main_data['fcsfw_express_disable'] !== 'yes' ) {
                        $this->add_rate($rate);
                    }



                    //$woocommerce->cart->add_fee( 'Duty:'.$key, 1, false, 'standard' );
                    //$woocommerce->cart->add_fee( 'SalesTax:', 1, false, 'standard' );
                    }
                }





                // If terms of trade is set to Customs Dutied Paid add feed to cart
                // Fee #1 SalesTax 
                // Fee #2 Duty
                
                if ($main_data['TermsOfTrade'] == "DDP"){
                    //$my_param = 'my theme name';
                    add_filter('woocommerce_cart_calculate_fees', function () use ($additional_fees) {
                        //$my_param is available for you now
                        global $woocommerce;
                        //$chosen_shipping_methods = WC()->session->get( 'chosen_shipping_methods' );
                        $chosen_shipping_methods = WC()->session->get( 'chosen_shipping_methods' );
                        //fcsfw_logger($chosen_shipping_methods[0]);
                        //$transient = 'flavorcloud_method_fees_' . $chosen_shipping_methods[0];
                        //set_transient( $transient, $additional_fees, 12 * HOUR_IN_SECONDS );
                        //$transient = 'flavorcloud_method_' . json_encode($args);

                        //$cached_response  = get_transient($transient);


                        //$this->debug(fcsfw_print_array($additional_fees));
                        //DutyHashKey 
                        if (fcsfw_contains('Standard', $chosen_shipping_methods[0])) {
                            $woocommerce->cart->add_fee( 'Duty:', $additional_fees['Standard']['Duty'], false, 'standard' );
                            $woocommerce->cart->add_fee( 'SalesTax:', $additional_fees['Standard']['SalesTax'], false, 'standard' );
                        } else if (fcsfw_contains('Express', $chosen_shipping_methods[0])) {
                            $woocommerce->cart->add_fee( 'Duty:', $additional_fees['Express']['Duty'], false, 'standard' );
                            $woocommerce->cart->add_fee( 'SalesTax:', $additional_fees['Express']['SalesTax'], false, 'standard' );
                        } else if (fcsfw_contains('Economy', $chosen_shipping_methods[0])){
                            $woocommerce->cart->add_fee( 'Duty:', $additional_fees['Economy']['Duty'], false, 'standard' );
                            $woocommerce->cart->add_fee( 'SalesTax:', $additional_fees['Economy']['SalesTax'], false, 'standard' );
                        }
                        
                    }, 99, 1);

                }










            }
  }

}