<?php

    use DVDoug\BoxPacker\Packer;
    use DVDoug\BoxPacker\FlavorCloud\FlavorCloudBox;  // use custom `Box` implementation
    use DVDoug\BoxPacker\FlavorCloud\FlavorCloudItem; // use custom `Item` implementation

    $packer = new Packer();

    use UnitConverter\UnitConverter;
    
    $converter = UnitConverter::createBuilder()
    ->addSimpleCalculator()
    ->addDefaultRegistry()
    ->build();

    /*
     * Add choices of box type - in this example the dimensions are passed in directly via constructor,
     * but for real code you would probably pass in objects retrieved from a database instead
     */
    // Reference for box type (e.g. SKU or description).
    // Outer width in mm.
    // Outer length in mm.
    // Outer depth in mm.
    // Empty weight in g.
    // Inner width in mm.
    // Inner length in mm.
    // Inner depth in mm.
    // Max weight the packaging can hold in g.
    //$packer->addBox(new FlavorCloudBox('Le petite box', 300, 300, 10, 10, 296, 296, 8, 1000));
    //$packer->addBox(new FlavorCloudBox('Le grande box', 3000, 3000, 100, 100, 2960, 2960, 80, 10000));
    foreach ( $boxes as $box ) {
       $packer->addBox(new FlavorCloudBox($box['Name'], 
       $converter->convert($box['Width'])->from("in")->to("mm"), 
       $converter->convert($box['Length'])->from("in")->to("mm"), 
       $converter->convert($box['Height'])->from("in")->to("mm"), 
       $converter->convert($box['Weight'])->from("lb")->to("g"), 
       $converter->convert($box['Width'])->from("in")->to("mm"), 
       $converter->convert($box['Length'])->from("in")->to("mm"), 
       $converter->convert($box['Height'])->from("in")->to("mm"), 
       $converter->convert($box['MaxWeight'])->from("lb")->to("g")
    ));

/*
    echo 'Width:'.$box['Width'];
    echo '</br>';
    echo 'Length:'.$box['Length'];
    echo '</br>';
    echo 'Height:'.$box['Height'];
    echo '</br>';
    echo 'Weight:'.$box['Weight'];
    echo '</br>';
    //echo 'Width-CM:'.($converter->convert($box['Width'])->from("in")->to("cm"));
    //echo 'Width-CM:'.($converter->convert($box['Length'])->from("in")->to("cm"));
    //echo 'Width-CM:'.($converter->convert($box['Height'])->from("in")->to("cm"));
    echo 'MaxWeight:'.$box['MaxWeight'];
    echo '</br>';
    echo '</br>';

    echo 'Width-CM:'.($converter->convert($box['Width'])->from("in")->to("cm"));
    echo '</br>';
    echo 'Length-CM:'.($converter->convert($box['Length'])->from("in")->to("cm"));
    echo '</br>';
    echo 'Height-CM:'.($converter->convert($box['Height'])->from("in")->to("cm"));
    echo '</br>';
    echo 'Weight-Grams:'.($converter->convert($box['Weight'])->from("lb")->to("g"));
    echo '</br>';
    //echo 'Width-CM:'.($converter->convert($box['Width'])->from("in")->to("cm"));
    //echo 'Width-CM:'.($converter->convert($box['Length'])->from("in")->to("cm"));
    //echo 'Width-CM:'.($converter->convert($box['Height'])->from("in")->to("cm"));
    echo 'MaxWeight-Grams:'.($converter->convert($box['MaxWeight'])->from("lb")->to("g"));
    echo '</br>';
    echo '</br>';
*/
    }


    /*
     * Add items to be packed - e.g. from shopping cart stored in user session. Again, the dimensional information
     * (and keep-flat requirement) would normally come from a DB
     */
    //$this->debug( fcsfw_print_array($items ) );
    /*
    // Width in mm.
    // Length in mm.
    // Depth in mm.
    // Weight in g.
    [Name] => Hoodie with Logo
    [Width] => 2
    [Length] => 2
    [Height] => 3
    [Weight] => 2
    [Quantity] => 1
    */
    //$packer->addItem(new FlavorCloudItem('Item 1', 2, 2, 1, 20, true), 10); // item, quantity
    //$packer->addItem(new FlavorCloudItem('Item 2', 250, 250, 12, 200, true), 2);
    //$packer->addItem(new FlavorCloudItem('Item 3', 250, 250, 24, 200, false), 1);
    foreach($items as $item) {
        //$this->debug( fcsfw_print_array($item));
        //$this->debug( fcsfw_print_array($item['Weight']));
        //$this->debug( fcsfw_print_array($converter->convert($item['Weight'])->from("lb")->to("g")));
        $packer->addItem(new FlavorCloudItem(
        $item['Name'], 
        $converter->convert($item['Width'])->from("in")->to("mm"), 
        $converter->convert($item['Length'])->from("in")->to("mm"), 
        $converter->convert($item['Height'])->from("in")->to("mm"), 
        $converter->convert($item['Weight'])->from("lb")->to("g"), true), $item['Quantity']); // item, quantity
    }

    $packedBoxes = $packer->pack();
    

/*
    foreach ($packedBoxes as $packedBox) {
        $boxType = $packedBox->getBox();
        fcsfw_print_array($boxType);
    }
*/
    //echo "These items fitted into " . count($packedBoxes) . " box(es)" . PHP_EOL;
    foreach ($packedBoxes as $packedBox) {
        $boxType = $packedBox->getBox(); // your own box object, in this case TestBox
        //echo "This box is a {$boxType->getReference()}, it is {$converter->convert($boxType->getOuterWidth())->from("cm")->to("in")}in wide, {$converter->convert($boxType->getOuterLength())->from("cm")->to("in")}in long and {$converter->convert($boxType->getOuterDepth())->from("cm")->to("in")}in high" . PHP_EOL;
        //echo "The combined weight of this box and the items inside it is {$packedBox->getWeight()}g" . PHP_EOL;

         //echo "The items in this box are:" . PHP_EOL;
        // $packedItems = $packedBox->getItems();
        // foreach ($packedItems as $packedItem) { // $packedItem->getItem() is your own item object, in this case TestItem
        //    echo $packedItem->getItem()->getDescription() . PHP_EOL;
        // }
        // break;
        //$this->debug( fcsfw_print_array($boxType->getReference()));
        //$key = array_search('Medium', $boxes);
        //$key = array_search('Medium', $boxes);
        //$this->debug( fcsfw_print_array(array_search(0, $boxes)));
        //$this->debug( fcsfw_print_array($boxes));

        //fcsfw_print_array($boxes);


        $quote_box = array(
            'Name' => $boxType->getReference(),
            'Length' => $converter->convert($boxType->getOuterLength())->from("mm")->to("in"),
            'Width'  => $converter->convert($boxType->getOuterWidth())->from("mm")->to("in"),
            'Height' => $converter->convert($boxType->getOuterDepth())->from("mm")->to("in"),
            'Weight' => $converter->convert($boxType->getEmptyWeight())->from("g")->to("lb")
        );


// Do to Imperial to Metric then back conversion, we want to get the original box array here 
foreach ($boxes as $box) {
  if ($box['Name'] == $boxType->getReference()) {
    $quote_box = $box;
    break;
  }
}

//fcsfw_print_array($item)
        
        // Stop processing at 1 Box , extend this function for multi box support. 
        break;
    }

